Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Call ¶
type Call struct {
// contains filtered or unexported fields
}
Call the dom and sends a message back to the application
type Class ¶
type Class struct {
// contains filtered or unexported fields
}
Class is a reference that can be used more than once
type ID ¶
type ID struct {
// contains filtered or unexported fields
}
ID is a reference that is expected to be used at-most once
type Listener ¶
Listener is a subscription that allows the component to be sent messages whenever an event was triggered on objects identified by the refs during the capture phase.
func NewListener ¶
NewListener will create a new event listener subscription
func (*Listener) Start ¶
type Navigate ¶
type Navigate struct {
// contains filtered or unexported fields
}
Navigate is the command that allows components to navigate the user
type PreventDefault ¶
type PreventDefault struct{}
PreventDefault can be embedded into message to signal to the platform that the default action of an event should not be executed
func (PreventDefault) DoPreventDefault ¶
func (pd PreventDefault) DoPreventDefault() bool
type Read ¶
type Read struct {
// contains filtered or unexported fields
}
Read reads the dom and sends a message back to the application
type Ref ¶
Ref provides operation on view elements. If the indicates that is an identity reference the platform can assume there is only element with this reference to speed up the search.
type StopPropagation ¶
type StopPropagation struct{}
StopPropagation can be embedded into a message to signal to the platform that the source event should not bubble further
func (StopPropagation) DoStopPropagation ¶
func (sp StopPropagation) DoStopPropagation() bool
Source Files
¶
- call.go
- dom.go
- listener.go
- nav.go
- read.go
- ref.go